# Exploration
This folder contains various experimentation that was done during the prototyping of inspec. 
Here you will find potential features, failed implementations and other curiosities.
We do not advise that you use this folder's code as is, since it is untested and often incomplete. 